Summary:	A GNU file archiving program
Name:		tar
Version:	1.31
%define		subrel 1
Release:	%mkrel 1
License:	GPLv3
Group:		Archiving/Backup
URL:		http://www.gnu.org/software/tar/tar.html
Source0:	ftp://ftp.gnu.org/gnu/tar/%{name}-%{version}.tar.xz
Source1:	ftp://ftp.gnu.org/gnu/tar/%{name}-%{version}.tar.xz.sig
Source2:	%{name}-help2man.bz2
Patch0:		tar-1.30-fix-buffer-overflow.patch
Patch1:		tar-1.29-lzma.patch
Patch2:		tar-1.31-check-return-from-find_next_block.patch
BuildRequires:	bison
BuildRequires:	xz
BuildRequires:	texinfo
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	gettext-devel
BuildRequires:	libacl-devel

# Required for the checks
BuildRequires:	attr
BuildRequires:	acl
BuildRequires:	policycoreutils


%description
The GNU tar program saves many files together into one archive and
can restore individual files (or all of the files) from the archive.
Tar can also be used to add supplemental files to an archive and to
update or list files in the archive.

Tar includes multivolume support, automatic archive compression/
decompression, the ability to perform remote archives and the
ability to perform incremental and full backups.

If you want to use Tar for remote backups, you'll also need to
install the rmt package.

You should install the tar package, because you'll find its
compression and decompression utilities essential for working
with files.

%prep
%setup -q
%patch0 -p0
%patch1 -p0
%patch2 -p1

bzcat %{SOURCE2} > ./help2man
chmod +x ./help2man

xz ChangeLog

# (misc, 02-11-2010, sigpipe test do not pass on iurt )
sed -i 's/.*sigpipe.at.*//' tests/testsuite.at

# (kekepower, 2019-01-04, dirrem01 and dirrem02 fails on iurt)
sed -i 's/.*dirrem01.*//' tests/testsuite.at
sed -i 's/.*dirrem02.*//' tests/testsuite.at

rm -f tests/testsuite

%build
autoreconf -vfi
%configure2_5x \
	--enable-backup-scripts \
	--with-lzma="xz --format=lzma" \
	DEFAULT_RMT_DIR=%{_sbindir} \
	--disable-rpath \
	RSH=/usr/bin/ssh

%make_build

# thanks to diffutils Makefile rule
(echo '[NAME]' && sed 's@/\* *@@; s/-/\\-/; q' src/tar.c) | (./help2man -i - -S '%{name} %{version}' src/tar ) | sed 's/^\.B info .*/.B info %{name}/' > %{name}.1

%check
%__make check

%install
%make_install

ln -sf tar %{buildroot}%{_bindir}/gtar

install -D -m 644 tar.1 %{buildroot}%{_mandir}/man1/tar.1

# conflicts with coda-debug-backup
mv %{buildroot}%{_sbindir}/backup %{buildroot}%{_sbindir}/tar-backup
mv %{buildroot}%{_sbindir}/restore %{buildroot}%{_sbindir}/tar-restore

# rmt is provided by rmt ...
mv %{buildroot}%{_sbindir}/rmt %{buildroot}%{_sbindir}/rmt-tar
mv %{buildroot}%{_mandir}/man8/rmt.8 %{buildroot}%{_mandir}/man8/rmt-tar.8

%find_lang %{name}

%post
%_install_info %{name}.info

%preun
%_remove_install_info %{name}.info

%files -f %{name}.lang
%doc AUTHORS ChangeLog.xz NEWS README THANKS TODO
%{_bindir}/*
%{_libexecdir}/backup.sh
%{_libexecdir}/dump-remind
%{_sbindir}/*
%{_infodir}/*.info*
%{_mandir}/man?/*


%changelog
* Fri May 03 2019 kekepower <kekepower> 1.31-1.1.mga6
+ Revision: 1396323
- Add upstream patch to fix CVE-2019-9923 (mga#24756)
- Update to version 1.31 to fix CVE-2018-20482 (mga#24117)

* Wed Nov 16 2016 neoclust <neoclust> 1.29-3.mga6
+ Revision: 1067523
- Add P2: Fix CVE-2016-6321

* Sat May 21 2016 luigiwalser <luigiwalser> 1.29-2.mga6
+ Revision: 1017377
- fix incorrectly rediffed patch1
+ shlomif <shlomif>
- Remove old patches

* Tue May 17 2016 yuri_myasoedov <yuri_myasoedov> 1.29-1.mga6
+ Revision: 1016500
- update to new version 1.29.
- update patches.
- replace %%makeinstall_std with %%make_install.
- replace %%make with %%make_build.

* Fri Feb 12 2016 umeabot <umeabot> 1.28-5.mga6
+ Revision: 958977
- Mageia 6 Mass Rebuild

* Fri Aug 21 2015 tmb <tmb> 1.28-4.mga6
+ Revision: 867900
- rebuild for new gcc

* Wed Oct 15 2014 umeabot <umeabot> 1.28-3.mga5
+ Revision: 748813
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.28-2.mga5
+ Revision: 689693
- Mageia 5 Mass Rebuild

* Wed Jul 30 2014 luigiwalser <luigiwalser> 1.28-1.mga5
+ Revision: 658373
- 1.28
- fix typo in lzma patch
- BR texinfo for makeinfo command
- remove ancient conflicts
- look for rmt command in the correct location
- UsrMove-related SPEC fixes
- fix rmt-tar man page name

* Wed Dec 11 2013 shlomif <shlomif> 1.27.1-1.mga4
+ Revision: 556257
- New version 1.27.1

* Mon Oct 21 2013 umeabot <umeabot> 1.27-2.mga4
+ Revision: 539656
- Mageia 4 Mass Rebuild
+ shlomif <shlomif>
- Remove old patch

* Mon Oct 07 2013 shlomif <shlomif> 1.27-1.mga4
+ Revision: 492674
- New version 1.27

* Mon Jan 14 2013 umeabot <umeabot> 1.26-4.mga3
+ Revision: 384040
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 pterjan <pterjan> 1.26-3.mga3
+ Revision: 340121
- Fix for _libdir != _libexecdir

* Wed Dec 05 2012 cjw <cjw> 1.26-2.mga3
+ Revision: 327044
- patch2: fix build error with glibc 2.16

* Wed Apr 13 2011 tv <tv> 1.26-1.mga2
+ Revision: 84589
- new release

* Sat Jan 08 2011 blino <blino> 1.25-1.mga1
+ Revision: 543
- imported package tar

